import type { default as NodeBundlr, WebBundlr } from '@bundlr-network/client';
import { Context, GenericFile, Keypair, Signer, SolAmount, UploaderInterface } from '@metaplex-foundation/umi-core';
import { Connection as Web3JsConnection, PublicKey as Web3JsPublicKey, SendOptions as Web3JsSendOptions, Signer as Web3JsSigner, Transaction as Web3JsTransaction, TransactionSignature as Web3JsTransactionSignature } from '@solana/web3.js';
export type BundlrUploaderOptions = {
    address?: string;
    timeout?: number;
    providerUrl?: string;
    priceMultiplier?: number;
    payer?: Signer;
};
export type BundlrWalletAdapter = {
    publicKey: Web3JsPublicKey | null;
    signMessage?: (message: Uint8Array) => Promise<Uint8Array>;
    signTransaction?: (transaction: Web3JsTransaction) => Promise<Web3JsTransaction>;
    signAllTransactions?: (transactions: Web3JsTransaction[]) => Promise<Web3JsTransaction[]>;
    sendTransaction: (transaction: Web3JsTransaction, connection: Web3JsConnection, options?: Web3JsSendOptions & {
        signers?: Web3JsSigner[];
    }) => Promise<Web3JsTransactionSignature>;
};
export declare class BundlrUploader implements UploaderInterface {
    protected context: Pick<Context, 'rpc' | 'payer' | 'eddsa'>;
    protected options: BundlrUploaderOptions;
    protected _bundlr: WebBundlr | NodeBundlr | null;
    constructor(context: Pick<Context, 'rpc' | 'payer' | 'eddsa'>, options?: BundlrUploaderOptions);
    getUploadPriceFromBytes(bytes: number): Promise<SolAmount>;
    getUploadPrice(files: GenericFile[]): Promise<SolAmount>;
    upload(files: GenericFile[]): Promise<string[]>;
    uploadJson<T>(json: T): Promise<string>;
    getBalance(): Promise<SolAmount>;
    fund(amount: SolAmount, skipBalanceCheck?: boolean): Promise<void>;
    withdrawAll(): Promise<void>;
    withdraw(amount: SolAmount): Promise<void>;
    bundlr(): Promise<WebBundlr | NodeBundlr>;
    initBundlr(): Promise<WebBundlr | NodeBundlr>;
    initNodeBundlr(address: string, currency: string, keypair: Keypair, options: any): Promise<NodeBundlr>;
    initWebBundlr(address: string, currency: string, payer: Signer, options: any): Promise<WebBundlr>;
}
export declare const isBundlrUploader: (uploader: UploaderInterface) => uploader is BundlrUploader;
